@@ -20,12 +20,13 @@
 #ifndef COMMON_H_
 #define COMMON_H_
 
-#include <gtk/gtk.h>
-
 const gchar *
 get_secondary_text_color();
 
 gchar *
 get_timestamp (time_t t);
 
+gchar *
+get_timestamp_full (time_t t);
+
 #endif /* COMMON_H_ */
